#include "nv_push_clcbc0.h"

#include <stdio.h>

#include "util/u_math.h"





const char *P_PARSE_NVC9C0_MTHD(uint16_t idx) ATTRIBUTE_COLD;
void P_DUMP_NVC9C0_MTHD_DATA(FILE *fp, uint16_t idx, uint32_t data,
                                   const char *prefix) ATTRIBUTE_COLD;

const char*
P_PARSE_NVCBC0_MTHD(uint16_t idx)
{
    switch (idx) {

  
        
    case NVCBC0_SET_OBJECT:

        
    case NVCBC0_NO_OPERATION:

        
    case NVCBC0_SET_NOTIFY_B:

        
    case NVCBC0_NOTIFY:

        
    case NVCBC0_WAIT_FOR_IDLE:

        
    case NVCBC0_LOAD_MME_INSTRUCTION_RAM_POINTER:

        
    case NVCBC0_LOAD_MME_INSTRUCTION_RAM:

        
    case NVCBC0_LOAD_MME_START_ADDRESS_RAM_POINTER:

        
    case NVCBC0_LOAD_MME_START_ADDRESS_RAM:

        
    case NVCBC0_SET_MME_SHADOW_RAM_CONTROL:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_A:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_B:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_C:

        
    case NVCBC0_SEND_GO_IDLE:

        
    case NVCBC0_PM_TRIGGER:

        
    case NVCBC0_PM_TRIGGER_WFI:

        
    case NVCBC0_FE_ATOMIC_SEQUENCE_BEGIN:

        
    case NVCBC0_FE_ATOMIC_SEQUENCE_END:

        
    case NVCBC0_SET_INSTRUMENTATION_METHOD_HEADER:

        
    case NVCBC0_SET_INSTRUMENTATION_METHOD_DATA:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_PAYLOAD_LOWER:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_PAYLOAD_UPPER:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_ADDRESS_LOWER:

        
    case NVCBC0_REPORT_SEMAPHORE_EXECUTE:

        
    case NVCBC0_LINE_LENGTH_IN:

        
    case NVCBC0_LINE_COUNT:

        
    case NVCBC0_OFFSET_OUT:

        
    case NVCBC0_PITCH_OUT:

        
    case NVCBC0_SET_DST_BLOCK_SIZE:

        
    case NVCBC0_SET_DST_WIDTH:

        
    case NVCBC0_SET_DST_HEIGHT:

        
    case NVCBC0_SET_DST_DEPTH:

        
    case NVCBC0_SET_DST_LAYER:

        
    case NVCBC0_SET_DST_ORIGIN_BYTES_X:

        
    case NVCBC0_SET_DST_ORIGIN_SAMPLES_Y:

        
    case NVCBC0_LAUNCH_DMA:

        
    case NVCBC0_LOAD_INLINE_DATA:

        
    case NVCBC0_SET_I2M_SEMAPHORE_B:

        
    case NVCBC0_SET_I2M_SEMAPHORE_C:

        
    case NVCBC0_SET_SM_SCG_CONTROL:

        
    case NVCBC0_SET_MME_SWITCH_STATE:

        
    case NVCBC0_SET_I2M_SPARE_NOOP00:

        
    case NVCBC0_SET_I2M_SPARE_NOOP01:

        
    case NVCBC0_SET_I2M_SPARE_NOOP02:

        
    case NVCBC0_SET_I2M_SPARE_NOOP03:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_A:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_B:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_C:

        
    case NVCBC0_PERFMON_TRANSFER:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_BASE_A:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_BASE_B:

        
    case NVCBC0_INVALIDATE_SHADER_CACHES:

        
    case NVCBC0_SET_RESERVED_SW_METHOD00:

        
    case NVCBC0_SET_RESERVED_SW_METHOD01:

        
    case NVCBC0_SET_RESERVED_SW_METHOD02:

        
    case NVCBC0_SET_RESERVED_SW_METHOD03:

        
    case NVCBC0_SET_RESERVED_SW_METHOD04:

        
    case NVCBC0_SET_RESERVED_SW_METHOD05:

        
    case NVCBC0_SET_RESERVED_SW_METHOD06:

        
    case NVCBC0_SET_RESERVED_SW_METHOD07:

        
    case NVCBC0_INVALIDATE_TEXTURE_HEADER_CACHE_NO_WFI:

        
    case NVCBC0_SET_CWD_REF_COUNTER:

        
    case NVCBC0_SET_RESERVED_SW_METHOD08:

        
    case NVCBC0_SET_RESERVED_SW_METHOD09:

        
    case NVCBC0_SET_RESERVED_SW_METHOD10:

        
    case NVCBC0_SET_RESERVED_SW_METHOD11:

        
    case NVCBC0_SET_RESERVED_SW_METHOD12:

        
    case NVCBC0_SET_RESERVED_SW_METHOD13:

        
    case NVCBC0_SET_RESERVED_SW_METHOD14:

        
    case NVCBC0_SET_RESERVED_SW_METHOD15:

        
    case NVCBC0_SET_COMPUTE_CLASS_VERSION:

        
    case NVCBC0_CHECK_COMPUTE_CLASS_VERSION:

        
    case NVCBC0_SET_QMD_VERSION:

        
    case NVCBC0_INVALIDATE_SKED_CACHES:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_CONTROL:

        
    case NVCBC0_SET_SHADER_SHARED_MEMORY_WINDOW_A:

        
    case NVCBC0_SET_SHADER_SHARED_MEMORY_WINDOW_B:

        
    case NVCBC0_SET_CWD_SLOT_COUNT:

        
    case NVCBC0_SEND_PCAS_A:

        
    case NVCBC0_SEND_PCAS_B:

        
    case NVCBC0_SEND_SIGNALING_PCAS_B:

        
    case NVCBC0_SEND_SIGNALING_PCAS2_B:

        
    case NVCBC0_SET_SKED_CACHE_CONTROL:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_A:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_B:

        
    case NVCBC0_SET_SPA_VERSION:

        
    case NVCBC0_SET_INLINE_QMD_ADDRESS_B:

        
    case NVCBC0_LOAD_INLINE_QMD_DATA(0):
    case NVCBC0_LOAD_INLINE_QMD_DATA(1):
    case NVCBC0_LOAD_INLINE_QMD_DATA(2):
    case NVCBC0_LOAD_INLINE_QMD_DATA(3):
    case NVCBC0_LOAD_INLINE_QMD_DATA(4):
    case NVCBC0_LOAD_INLINE_QMD_DATA(5):
    case NVCBC0_LOAD_INLINE_QMD_DATA(6):
    case NVCBC0_LOAD_INLINE_QMD_DATA(7):
    case NVCBC0_LOAD_INLINE_QMD_DATA(8):
    case NVCBC0_LOAD_INLINE_QMD_DATA(9):
    case NVCBC0_LOAD_INLINE_QMD_DATA(10):
    case NVCBC0_LOAD_INLINE_QMD_DATA(11):
    case NVCBC0_LOAD_INLINE_QMD_DATA(12):
    case NVCBC0_LOAD_INLINE_QMD_DATA(13):
    case NVCBC0_LOAD_INLINE_QMD_DATA(14):
    case NVCBC0_LOAD_INLINE_QMD_DATA(15):
    case NVCBC0_LOAD_INLINE_QMD_DATA(16):
    case NVCBC0_LOAD_INLINE_QMD_DATA(17):
    case NVCBC0_LOAD_INLINE_QMD_DATA(18):
    case NVCBC0_LOAD_INLINE_QMD_DATA(19):
    case NVCBC0_LOAD_INLINE_QMD_DATA(20):
    case NVCBC0_LOAD_INLINE_QMD_DATA(21):
    case NVCBC0_LOAD_INLINE_QMD_DATA(22):
    case NVCBC0_LOAD_INLINE_QMD_DATA(23):
    case NVCBC0_LOAD_INLINE_QMD_DATA(24):
    case NVCBC0_LOAD_INLINE_QMD_DATA(25):
    case NVCBC0_LOAD_INLINE_QMD_DATA(26):
    case NVCBC0_LOAD_INLINE_QMD_DATA(27):
    case NVCBC0_LOAD_INLINE_QMD_DATA(28):
    case NVCBC0_LOAD_INLINE_QMD_DATA(29):
    case NVCBC0_LOAD_INLINE_QMD_DATA(30):
    case NVCBC0_LOAD_INLINE_QMD_DATA(31):
    case NVCBC0_LOAD_INLINE_QMD_DATA(32):
    case NVCBC0_LOAD_INLINE_QMD_DATA(33):
    case NVCBC0_LOAD_INLINE_QMD_DATA(34):
    case NVCBC0_LOAD_INLINE_QMD_DATA(35):
    case NVCBC0_LOAD_INLINE_QMD_DATA(36):
    case NVCBC0_LOAD_INLINE_QMD_DATA(37):
    case NVCBC0_LOAD_INLINE_QMD_DATA(38):
    case NVCBC0_LOAD_INLINE_QMD_DATA(39):
    case NVCBC0_LOAD_INLINE_QMD_DATA(40):
    case NVCBC0_LOAD_INLINE_QMD_DATA(41):
    case NVCBC0_LOAD_INLINE_QMD_DATA(42):
    case NVCBC0_LOAD_INLINE_QMD_DATA(43):
    case NVCBC0_LOAD_INLINE_QMD_DATA(44):
    case NVCBC0_LOAD_INLINE_QMD_DATA(45):
    case NVCBC0_LOAD_INLINE_QMD_DATA(46):
    case NVCBC0_LOAD_INLINE_QMD_DATA(47):
    case NVCBC0_LOAD_INLINE_QMD_DATA(48):
    case NVCBC0_LOAD_INLINE_QMD_DATA(49):
    case NVCBC0_LOAD_INLINE_QMD_DATA(50):
    case NVCBC0_LOAD_INLINE_QMD_DATA(51):
    case NVCBC0_LOAD_INLINE_QMD_DATA(52):
    case NVCBC0_LOAD_INLINE_QMD_DATA(53):
    case NVCBC0_LOAD_INLINE_QMD_DATA(54):
    case NVCBC0_LOAD_INLINE_QMD_DATA(55):
    case NVCBC0_LOAD_INLINE_QMD_DATA(56):
    case NVCBC0_LOAD_INLINE_QMD_DATA(57):
    case NVCBC0_LOAD_INLINE_QMD_DATA(58):
    case NVCBC0_LOAD_INLINE_QMD_DATA(59):
    case NVCBC0_LOAD_INLINE_QMD_DATA(60):
    case NVCBC0_LOAD_INLINE_QMD_DATA(61):
    case NVCBC0_LOAD_INLINE_QMD_DATA(62):
    case NVCBC0_LOAD_INLINE_QMD_DATA(63):

        
    case NVCBC0_SET_FALCON00:

        
    case NVCBC0_SET_FALCON01:

        
    case NVCBC0_SET_FALCON02:

        
    case NVCBC0_SET_FALCON03:

        
    case NVCBC0_SET_FALCON04:

        
    case NVCBC0_SET_FALCON05:

        
    case NVCBC0_SET_FALCON06:

        
    case NVCBC0_SET_FALCON07:

        
    case NVCBC0_SET_FALCON08:

        
    case NVCBC0_SET_FALCON09:

        
    case NVCBC0_SET_FALCON10:

        
    case NVCBC0_SET_FALCON11:

        
    case NVCBC0_SET_FALCON12:

        
    case NVCBC0_SET_FALCON13:

        
    case NVCBC0_SET_FALCON14:

        
    case NVCBC0_SET_FALCON15:

        
    case NVCBC0_SET_MME_MEM_ADDRESS_B:

        
    case NVCBC0_SET_MME_DATA_RAM_ADDRESS:

        
    case NVCBC0_MME_DMA_READ:

        
    case NVCBC0_MME_DMA_READ_FIFOED:

        
    case NVCBC0_MME_DMA_WRITE:

        
    case NVCBC0_MME_DMA_REDUCTION:

        
    case NVCBC0_MME_DMA_SYSMEMBAR:

        
    case NVCBC0_MME_DMA_SYNC:

        
    case NVCBC0_SET_MME_DATA_FIFO_CONFIG:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_B:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_WINDOW_A:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_WINDOW_B:

        
    case NVCBC0_THROTTLE_SM:

        
    case NVCBC0_SET_SHADER_CACHE_CONTROL:

        
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(0):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(1):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(2):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(3):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(4):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(5):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(6):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(7):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(8):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(9):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(10):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(11):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(12):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(13):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(14):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(15):

        
    case NVCBC0_SET_SM_TIMEOUT_INTERVAL:

        
    case NVCBC0_MME_DMA_WRITE_METHOD_BARRIER:

        
    case NVCBC0_INVALIDATE_TEXTURE_DATA_CACHE_NO_WFI:

        
    case NVCBC0_ACTIVATE_PERF_SETTINGS_FOR_COMPUTE_CONTEXT:

        
    case NVCBC0_INVALIDATE_SAMPLER_CACHE:

        
    case NVCBC0_INVALIDATE_TEXTURE_HEADER_CACHE:

        
    case NVCBC0_INVALIDATE_TEXTURE_DATA_CACHE:

        
    case NVCBC0_INVALIDATE_SAMPLER_CACHE_NO_WFI:

        
    case NVCBC0_SET_SHADER_EXCEPTIONS:

        
    case NVCBC0_SET_RENDER_ENABLE_A:

        
    case NVCBC0_SET_RENDER_ENABLE_B:

        
    case NVCBC0_SET_RENDER_ENABLE_C:

        
    case NVCBC0_SET_TEX_SAMPLER_POOL_B:

        
    case NVCBC0_SET_TEX_SAMPLER_POOL_C:

        
    case NVCBC0_SET_TEX_HEADER_POOL_B:

        
    case NVCBC0_SET_TEX_HEADER_POOL_C:

        
    case NVCBC0_INVALIDATE_SHADER_CACHES_NO_WFI:

        
    case NVCBC0_SET_RENDER_ENABLE_OVERRIDE:

        
    case NVCBC0_PIPE_NOP:

        
    case NVCBC0_SET_SPARE00:

        
    case NVCBC0_SET_SPARE01:

        
    case NVCBC0_SET_SPARE02:

        
    case NVCBC0_SET_SPARE03:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_B:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_C:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_D:

        
    case NVCBC0_SET_TRAP_HANDLER_B:

        
    case NVCBC0_SET_BINDLESS_TEXTURE:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(7):

        
    case NVCBC0_ENABLE_SHADER_PERFORMANCE_SNAPSHOT_COUNTER:

        
    case NVCBC0_DISABLE_SHADER_PERFORMANCE_SNAPSHOT_COUNTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_TRAP_CONTROL:

        
    case NVCBC0_START_SHADER_PERFORMANCE_COUNTER:

        
    case NVCBC0_STOP_SHADER_PERFORMANCE_COUNTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_SCTL_FILTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CORE_MIO_FILTER:

        
    case NVCBC0_SET_MME_SHADOW_SCRATCH(0):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(1):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(2):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(3):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(4):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(5):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(6):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(7):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(8):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(9):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(10):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(11):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(12):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(13):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(14):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(15):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(16):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(17):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(18):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(19):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(20):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(21):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(22):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(23):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(24):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(25):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(26):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(27):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(28):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(29):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(30):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(31):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(32):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(33):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(34):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(35):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(36):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(37):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(38):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(39):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(40):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(41):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(42):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(43):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(44):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(45):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(46):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(47):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(48):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(49):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(50):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(51):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(52):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(53):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(54):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(55):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(56):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(57):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(58):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(59):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(60):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(61):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(62):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(63):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(64):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(65):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(66):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(67):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(68):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(69):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(70):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(71):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(72):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(73):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(74):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(75):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(76):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(77):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(78):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(79):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(80):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(81):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(82):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(83):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(84):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(85):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(86):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(87):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(88):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(89):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(90):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(91):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(92):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(93):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(94):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(95):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(96):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(97):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(98):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(99):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(100):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(101):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(102):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(103):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(104):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(105):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(106):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(107):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(108):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(109):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(110):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(111):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(112):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(113):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(114):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(115):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(116):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(117):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(118):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(119):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(120):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(121):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(122):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(123):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(124):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(125):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(126):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(127):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(128):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(129):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(130):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(131):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(132):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(133):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(134):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(135):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(136):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(137):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(138):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(139):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(140):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(141):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(142):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(143):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(144):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(145):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(146):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(147):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(148):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(149):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(150):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(151):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(152):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(153):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(154):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(155):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(156):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(157):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(158):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(159):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(160):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(161):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(162):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(163):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(164):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(165):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(166):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(167):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(168):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(169):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(170):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(171):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(172):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(173):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(174):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(175):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(176):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(177):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(178):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(179):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(180):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(181):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(182):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(183):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(184):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(185):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(186):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(187):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(188):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(189):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(190):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(191):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(192):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(193):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(194):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(195):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(196):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(197):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(198):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(199):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(200):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(201):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(202):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(203):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(204):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(205):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(206):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(207):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(208):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(209):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(210):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(211):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(212):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(213):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(214):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(215):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(216):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(217):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(218):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(219):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(220):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(221):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(222):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(223):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(224):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(225):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(226):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(227):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(228):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(229):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(230):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(231):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(232):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(233):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(234):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(235):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(236):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(237):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(238):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(239):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(240):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(241):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(242):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(243):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(244):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(245):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(246):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(247):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(248):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(249):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(250):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(251):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(252):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(253):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(254):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(255):

        
    case NVCBC0_CALL_MME_MACRO(0):
    case NVCBC0_CALL_MME_MACRO(1):
    case NVCBC0_CALL_MME_MACRO(2):
    case NVCBC0_CALL_MME_MACRO(3):
    case NVCBC0_CALL_MME_MACRO(4):
    case NVCBC0_CALL_MME_MACRO(5):
    case NVCBC0_CALL_MME_MACRO(6):
    case NVCBC0_CALL_MME_MACRO(7):
    case NVCBC0_CALL_MME_MACRO(8):
    case NVCBC0_CALL_MME_MACRO(9):
    case NVCBC0_CALL_MME_MACRO(10):
    case NVCBC0_CALL_MME_MACRO(11):
    case NVCBC0_CALL_MME_MACRO(12):
    case NVCBC0_CALL_MME_MACRO(13):
    case NVCBC0_CALL_MME_MACRO(14):
    case NVCBC0_CALL_MME_MACRO(15):
    case NVCBC0_CALL_MME_MACRO(16):
    case NVCBC0_CALL_MME_MACRO(17):
    case NVCBC0_CALL_MME_MACRO(18):
    case NVCBC0_CALL_MME_MACRO(19):
    case NVCBC0_CALL_MME_MACRO(20):
    case NVCBC0_CALL_MME_MACRO(21):
    case NVCBC0_CALL_MME_MACRO(22):
    case NVCBC0_CALL_MME_MACRO(23):
    case NVCBC0_CALL_MME_MACRO(24):
    case NVCBC0_CALL_MME_MACRO(25):
    case NVCBC0_CALL_MME_MACRO(26):
    case NVCBC0_CALL_MME_MACRO(27):
    case NVCBC0_CALL_MME_MACRO(28):
    case NVCBC0_CALL_MME_MACRO(29):
    case NVCBC0_CALL_MME_MACRO(30):
    case NVCBC0_CALL_MME_MACRO(31):
    case NVCBC0_CALL_MME_MACRO(32):
    case NVCBC0_CALL_MME_MACRO(33):
    case NVCBC0_CALL_MME_MACRO(34):
    case NVCBC0_CALL_MME_MACRO(35):
    case NVCBC0_CALL_MME_MACRO(36):
    case NVCBC0_CALL_MME_MACRO(37):
    case NVCBC0_CALL_MME_MACRO(38):
    case NVCBC0_CALL_MME_MACRO(39):
    case NVCBC0_CALL_MME_MACRO(40):
    case NVCBC0_CALL_MME_MACRO(41):
    case NVCBC0_CALL_MME_MACRO(42):
    case NVCBC0_CALL_MME_MACRO(43):
    case NVCBC0_CALL_MME_MACRO(44):
    case NVCBC0_CALL_MME_MACRO(45):
    case NVCBC0_CALL_MME_MACRO(46):
    case NVCBC0_CALL_MME_MACRO(47):
    case NVCBC0_CALL_MME_MACRO(48):
    case NVCBC0_CALL_MME_MACRO(49):
    case NVCBC0_CALL_MME_MACRO(50):
    case NVCBC0_CALL_MME_MACRO(51):
    case NVCBC0_CALL_MME_MACRO(52):
    case NVCBC0_CALL_MME_MACRO(53):
    case NVCBC0_CALL_MME_MACRO(54):
    case NVCBC0_CALL_MME_MACRO(55):
    case NVCBC0_CALL_MME_MACRO(56):
    case NVCBC0_CALL_MME_MACRO(57):
    case NVCBC0_CALL_MME_MACRO(58):
    case NVCBC0_CALL_MME_MACRO(59):
    case NVCBC0_CALL_MME_MACRO(60):
    case NVCBC0_CALL_MME_MACRO(61):
    case NVCBC0_CALL_MME_MACRO(62):
    case NVCBC0_CALL_MME_MACRO(63):
    case NVCBC0_CALL_MME_MACRO(64):
    case NVCBC0_CALL_MME_MACRO(65):
    case NVCBC0_CALL_MME_MACRO(66):
    case NVCBC0_CALL_MME_MACRO(67):
    case NVCBC0_CALL_MME_MACRO(68):
    case NVCBC0_CALL_MME_MACRO(69):
    case NVCBC0_CALL_MME_MACRO(70):
    case NVCBC0_CALL_MME_MACRO(71):
    case NVCBC0_CALL_MME_MACRO(72):
    case NVCBC0_CALL_MME_MACRO(73):
    case NVCBC0_CALL_MME_MACRO(74):
    case NVCBC0_CALL_MME_MACRO(75):
    case NVCBC0_CALL_MME_MACRO(76):
    case NVCBC0_CALL_MME_MACRO(77):
    case NVCBC0_CALL_MME_MACRO(78):
    case NVCBC0_CALL_MME_MACRO(79):
    case NVCBC0_CALL_MME_MACRO(80):
    case NVCBC0_CALL_MME_MACRO(81):
    case NVCBC0_CALL_MME_MACRO(82):
    case NVCBC0_CALL_MME_MACRO(83):
    case NVCBC0_CALL_MME_MACRO(84):
    case NVCBC0_CALL_MME_MACRO(85):
    case NVCBC0_CALL_MME_MACRO(86):
    case NVCBC0_CALL_MME_MACRO(87):
    case NVCBC0_CALL_MME_MACRO(88):
    case NVCBC0_CALL_MME_MACRO(89):
    case NVCBC0_CALL_MME_MACRO(90):
    case NVCBC0_CALL_MME_MACRO(91):
    case NVCBC0_CALL_MME_MACRO(92):
    case NVCBC0_CALL_MME_MACRO(93):
    case NVCBC0_CALL_MME_MACRO(94):
    case NVCBC0_CALL_MME_MACRO(95):
    case NVCBC0_CALL_MME_MACRO(96):
    case NVCBC0_CALL_MME_MACRO(97):
    case NVCBC0_CALL_MME_MACRO(98):
    case NVCBC0_CALL_MME_MACRO(99):
    case NVCBC0_CALL_MME_MACRO(100):
    case NVCBC0_CALL_MME_MACRO(101):
    case NVCBC0_CALL_MME_MACRO(102):
    case NVCBC0_CALL_MME_MACRO(103):
    case NVCBC0_CALL_MME_MACRO(104):
    case NVCBC0_CALL_MME_MACRO(105):
    case NVCBC0_CALL_MME_MACRO(106):
    case NVCBC0_CALL_MME_MACRO(107):
    case NVCBC0_CALL_MME_MACRO(108):
    case NVCBC0_CALL_MME_MACRO(109):
    case NVCBC0_CALL_MME_MACRO(110):
    case NVCBC0_CALL_MME_MACRO(111):
    case NVCBC0_CALL_MME_MACRO(112):
    case NVCBC0_CALL_MME_MACRO(113):
    case NVCBC0_CALL_MME_MACRO(114):
    case NVCBC0_CALL_MME_MACRO(115):
    case NVCBC0_CALL_MME_MACRO(116):
    case NVCBC0_CALL_MME_MACRO(117):
    case NVCBC0_CALL_MME_MACRO(118):
    case NVCBC0_CALL_MME_MACRO(119):
    case NVCBC0_CALL_MME_MACRO(120):
    case NVCBC0_CALL_MME_MACRO(121):
    case NVCBC0_CALL_MME_MACRO(122):
    case NVCBC0_CALL_MME_MACRO(123):
    case NVCBC0_CALL_MME_MACRO(124):
    case NVCBC0_CALL_MME_MACRO(125):
    case NVCBC0_CALL_MME_MACRO(126):
    case NVCBC0_CALL_MME_MACRO(127):
    case NVCBC0_CALL_MME_MACRO(128):
    case NVCBC0_CALL_MME_MACRO(129):
    case NVCBC0_CALL_MME_MACRO(130):
    case NVCBC0_CALL_MME_MACRO(131):
    case NVCBC0_CALL_MME_MACRO(132):
    case NVCBC0_CALL_MME_MACRO(133):
    case NVCBC0_CALL_MME_MACRO(134):
    case NVCBC0_CALL_MME_MACRO(135):
    case NVCBC0_CALL_MME_MACRO(136):
    case NVCBC0_CALL_MME_MACRO(137):
    case NVCBC0_CALL_MME_MACRO(138):
    case NVCBC0_CALL_MME_MACRO(139):
    case NVCBC0_CALL_MME_MACRO(140):
    case NVCBC0_CALL_MME_MACRO(141):
    case NVCBC0_CALL_MME_MACRO(142):
    case NVCBC0_CALL_MME_MACRO(143):
    case NVCBC0_CALL_MME_MACRO(144):
    case NVCBC0_CALL_MME_MACRO(145):
    case NVCBC0_CALL_MME_MACRO(146):
    case NVCBC0_CALL_MME_MACRO(147):
    case NVCBC0_CALL_MME_MACRO(148):
    case NVCBC0_CALL_MME_MACRO(149):
    case NVCBC0_CALL_MME_MACRO(150):
    case NVCBC0_CALL_MME_MACRO(151):
    case NVCBC0_CALL_MME_MACRO(152):
    case NVCBC0_CALL_MME_MACRO(153):
    case NVCBC0_CALL_MME_MACRO(154):
    case NVCBC0_CALL_MME_MACRO(155):
    case NVCBC0_CALL_MME_MACRO(156):
    case NVCBC0_CALL_MME_MACRO(157):
    case NVCBC0_CALL_MME_MACRO(158):
    case NVCBC0_CALL_MME_MACRO(159):
    case NVCBC0_CALL_MME_MACRO(160):
    case NVCBC0_CALL_MME_MACRO(161):
    case NVCBC0_CALL_MME_MACRO(162):
    case NVCBC0_CALL_MME_MACRO(163):
    case NVCBC0_CALL_MME_MACRO(164):
    case NVCBC0_CALL_MME_MACRO(165):
    case NVCBC0_CALL_MME_MACRO(166):
    case NVCBC0_CALL_MME_MACRO(167):
    case NVCBC0_CALL_MME_MACRO(168):
    case NVCBC0_CALL_MME_MACRO(169):
    case NVCBC0_CALL_MME_MACRO(170):
    case NVCBC0_CALL_MME_MACRO(171):
    case NVCBC0_CALL_MME_MACRO(172):
    case NVCBC0_CALL_MME_MACRO(173):
    case NVCBC0_CALL_MME_MACRO(174):
    case NVCBC0_CALL_MME_MACRO(175):
    case NVCBC0_CALL_MME_MACRO(176):
    case NVCBC0_CALL_MME_MACRO(177):
    case NVCBC0_CALL_MME_MACRO(178):
    case NVCBC0_CALL_MME_MACRO(179):
    case NVCBC0_CALL_MME_MACRO(180):
    case NVCBC0_CALL_MME_MACRO(181):
    case NVCBC0_CALL_MME_MACRO(182):
    case NVCBC0_CALL_MME_MACRO(183):
    case NVCBC0_CALL_MME_MACRO(184):
    case NVCBC0_CALL_MME_MACRO(185):
    case NVCBC0_CALL_MME_MACRO(186):
    case NVCBC0_CALL_MME_MACRO(187):
    case NVCBC0_CALL_MME_MACRO(188):
    case NVCBC0_CALL_MME_MACRO(189):
    case NVCBC0_CALL_MME_MACRO(190):
    case NVCBC0_CALL_MME_MACRO(191):
    case NVCBC0_CALL_MME_MACRO(192):
    case NVCBC0_CALL_MME_MACRO(193):
    case NVCBC0_CALL_MME_MACRO(194):
    case NVCBC0_CALL_MME_MACRO(195):
    case NVCBC0_CALL_MME_MACRO(196):
    case NVCBC0_CALL_MME_MACRO(197):
    case NVCBC0_CALL_MME_MACRO(198):
    case NVCBC0_CALL_MME_MACRO(199):
    case NVCBC0_CALL_MME_MACRO(200):
    case NVCBC0_CALL_MME_MACRO(201):
    case NVCBC0_CALL_MME_MACRO(202):
    case NVCBC0_CALL_MME_MACRO(203):
    case NVCBC0_CALL_MME_MACRO(204):
    case NVCBC0_CALL_MME_MACRO(205):
    case NVCBC0_CALL_MME_MACRO(206):
    case NVCBC0_CALL_MME_MACRO(207):
    case NVCBC0_CALL_MME_MACRO(208):
    case NVCBC0_CALL_MME_MACRO(209):
    case NVCBC0_CALL_MME_MACRO(210):
    case NVCBC0_CALL_MME_MACRO(211):
    case NVCBC0_CALL_MME_MACRO(212):
    case NVCBC0_CALL_MME_MACRO(213):
    case NVCBC0_CALL_MME_MACRO(214):
    case NVCBC0_CALL_MME_MACRO(215):
    case NVCBC0_CALL_MME_MACRO(216):
    case NVCBC0_CALL_MME_MACRO(217):
    case NVCBC0_CALL_MME_MACRO(218):
    case NVCBC0_CALL_MME_MACRO(219):
    case NVCBC0_CALL_MME_MACRO(220):
    case NVCBC0_CALL_MME_MACRO(221):
    case NVCBC0_CALL_MME_MACRO(222):
    case NVCBC0_CALL_MME_MACRO(223):
    case NVCBC0_CALL_MME_MACRO(224):
    case NVCBC0_CALL_MME_MACRO(225):
    case NVCBC0_CALL_MME_MACRO(226):
    case NVCBC0_CALL_MME_MACRO(227):
    case NVCBC0_CALL_MME_MACRO(228):
    case NVCBC0_CALL_MME_MACRO(229):
    case NVCBC0_CALL_MME_MACRO(230):
    case NVCBC0_CALL_MME_MACRO(231):
    case NVCBC0_CALL_MME_MACRO(232):
    case NVCBC0_CALL_MME_MACRO(233):
    case NVCBC0_CALL_MME_MACRO(234):
    case NVCBC0_CALL_MME_MACRO(235):
    case NVCBC0_CALL_MME_MACRO(236):
    case NVCBC0_CALL_MME_MACRO(237):
    case NVCBC0_CALL_MME_MACRO(238):
    case NVCBC0_CALL_MME_MACRO(239):
    case NVCBC0_CALL_MME_MACRO(240):
    case NVCBC0_CALL_MME_MACRO(241):
    case NVCBC0_CALL_MME_MACRO(242):
    case NVCBC0_CALL_MME_MACRO(243):
    case NVCBC0_CALL_MME_MACRO(244):
    case NVCBC0_CALL_MME_MACRO(245):
    case NVCBC0_CALL_MME_MACRO(246):
    case NVCBC0_CALL_MME_MACRO(247):
    case NVCBC0_CALL_MME_MACRO(248):
    case NVCBC0_CALL_MME_MACRO(249):
    case NVCBC0_CALL_MME_MACRO(250):
    case NVCBC0_CALL_MME_MACRO(251):
    case NVCBC0_CALL_MME_MACRO(252):
    case NVCBC0_CALL_MME_MACRO(253):
    case NVCBC0_CALL_MME_MACRO(254):
    case NVCBC0_CALL_MME_MACRO(255):

        
    case NVCBC0_CALL_MME_DATA(0):
    case NVCBC0_CALL_MME_DATA(1):
    case NVCBC0_CALL_MME_DATA(2):
    case NVCBC0_CALL_MME_DATA(3):
    case NVCBC0_CALL_MME_DATA(4):
    case NVCBC0_CALL_MME_DATA(5):
    case NVCBC0_CALL_MME_DATA(6):
    case NVCBC0_CALL_MME_DATA(7):
    case NVCBC0_CALL_MME_DATA(8):
    case NVCBC0_CALL_MME_DATA(9):
    case NVCBC0_CALL_MME_DATA(10):
    case NVCBC0_CALL_MME_DATA(11):
    case NVCBC0_CALL_MME_DATA(12):
    case NVCBC0_CALL_MME_DATA(13):
    case NVCBC0_CALL_MME_DATA(14):
    case NVCBC0_CALL_MME_DATA(15):
    case NVCBC0_CALL_MME_DATA(16):
    case NVCBC0_CALL_MME_DATA(17):
    case NVCBC0_CALL_MME_DATA(18):
    case NVCBC0_CALL_MME_DATA(19):
    case NVCBC0_CALL_MME_DATA(20):
    case NVCBC0_CALL_MME_DATA(21):
    case NVCBC0_CALL_MME_DATA(22):
    case NVCBC0_CALL_MME_DATA(23):
    case NVCBC0_CALL_MME_DATA(24):
    case NVCBC0_CALL_MME_DATA(25):
    case NVCBC0_CALL_MME_DATA(26):
    case NVCBC0_CALL_MME_DATA(27):
    case NVCBC0_CALL_MME_DATA(28):
    case NVCBC0_CALL_MME_DATA(29):
    case NVCBC0_CALL_MME_DATA(30):
    case NVCBC0_CALL_MME_DATA(31):
    case NVCBC0_CALL_MME_DATA(32):
    case NVCBC0_CALL_MME_DATA(33):
    case NVCBC0_CALL_MME_DATA(34):
    case NVCBC0_CALL_MME_DATA(35):
    case NVCBC0_CALL_MME_DATA(36):
    case NVCBC0_CALL_MME_DATA(37):
    case NVCBC0_CALL_MME_DATA(38):
    case NVCBC0_CALL_MME_DATA(39):
    case NVCBC0_CALL_MME_DATA(40):
    case NVCBC0_CALL_MME_DATA(41):
    case NVCBC0_CALL_MME_DATA(42):
    case NVCBC0_CALL_MME_DATA(43):
    case NVCBC0_CALL_MME_DATA(44):
    case NVCBC0_CALL_MME_DATA(45):
    case NVCBC0_CALL_MME_DATA(46):
    case NVCBC0_CALL_MME_DATA(47):
    case NVCBC0_CALL_MME_DATA(48):
    case NVCBC0_CALL_MME_DATA(49):
    case NVCBC0_CALL_MME_DATA(50):
    case NVCBC0_CALL_MME_DATA(51):
    case NVCBC0_CALL_MME_DATA(52):
    case NVCBC0_CALL_MME_DATA(53):
    case NVCBC0_CALL_MME_DATA(54):
    case NVCBC0_CALL_MME_DATA(55):
    case NVCBC0_CALL_MME_DATA(56):
    case NVCBC0_CALL_MME_DATA(57):
    case NVCBC0_CALL_MME_DATA(58):
    case NVCBC0_CALL_MME_DATA(59):
    case NVCBC0_CALL_MME_DATA(60):
    case NVCBC0_CALL_MME_DATA(61):
    case NVCBC0_CALL_MME_DATA(62):
    case NVCBC0_CALL_MME_DATA(63):
    case NVCBC0_CALL_MME_DATA(64):
    case NVCBC0_CALL_MME_DATA(65):
    case NVCBC0_CALL_MME_DATA(66):
    case NVCBC0_CALL_MME_DATA(67):
    case NVCBC0_CALL_MME_DATA(68):
    case NVCBC0_CALL_MME_DATA(69):
    case NVCBC0_CALL_MME_DATA(70):
    case NVCBC0_CALL_MME_DATA(71):
    case NVCBC0_CALL_MME_DATA(72):
    case NVCBC0_CALL_MME_DATA(73):
    case NVCBC0_CALL_MME_DATA(74):
    case NVCBC0_CALL_MME_DATA(75):
    case NVCBC0_CALL_MME_DATA(76):
    case NVCBC0_CALL_MME_DATA(77):
    case NVCBC0_CALL_MME_DATA(78):
    case NVCBC0_CALL_MME_DATA(79):
    case NVCBC0_CALL_MME_DATA(80):
    case NVCBC0_CALL_MME_DATA(81):
    case NVCBC0_CALL_MME_DATA(82):
    case NVCBC0_CALL_MME_DATA(83):
    case NVCBC0_CALL_MME_DATA(84):
    case NVCBC0_CALL_MME_DATA(85):
    case NVCBC0_CALL_MME_DATA(86):
    case NVCBC0_CALL_MME_DATA(87):
    case NVCBC0_CALL_MME_DATA(88):
    case NVCBC0_CALL_MME_DATA(89):
    case NVCBC0_CALL_MME_DATA(90):
    case NVCBC0_CALL_MME_DATA(91):
    case NVCBC0_CALL_MME_DATA(92):
    case NVCBC0_CALL_MME_DATA(93):
    case NVCBC0_CALL_MME_DATA(94):
    case NVCBC0_CALL_MME_DATA(95):
    case NVCBC0_CALL_MME_DATA(96):
    case NVCBC0_CALL_MME_DATA(97):
    case NVCBC0_CALL_MME_DATA(98):
    case NVCBC0_CALL_MME_DATA(99):
    case NVCBC0_CALL_MME_DATA(100):
    case NVCBC0_CALL_MME_DATA(101):
    case NVCBC0_CALL_MME_DATA(102):
    case NVCBC0_CALL_MME_DATA(103):
    case NVCBC0_CALL_MME_DATA(104):
    case NVCBC0_CALL_MME_DATA(105):
    case NVCBC0_CALL_MME_DATA(106):
    case NVCBC0_CALL_MME_DATA(107):
    case NVCBC0_CALL_MME_DATA(108):
    case NVCBC0_CALL_MME_DATA(109):
    case NVCBC0_CALL_MME_DATA(110):
    case NVCBC0_CALL_MME_DATA(111):
    case NVCBC0_CALL_MME_DATA(112):
    case NVCBC0_CALL_MME_DATA(113):
    case NVCBC0_CALL_MME_DATA(114):
    case NVCBC0_CALL_MME_DATA(115):
    case NVCBC0_CALL_MME_DATA(116):
    case NVCBC0_CALL_MME_DATA(117):
    case NVCBC0_CALL_MME_DATA(118):
    case NVCBC0_CALL_MME_DATA(119):
    case NVCBC0_CALL_MME_DATA(120):
    case NVCBC0_CALL_MME_DATA(121):
    case NVCBC0_CALL_MME_DATA(122):
    case NVCBC0_CALL_MME_DATA(123):
    case NVCBC0_CALL_MME_DATA(124):
    case NVCBC0_CALL_MME_DATA(125):
    case NVCBC0_CALL_MME_DATA(126):
    case NVCBC0_CALL_MME_DATA(127):
    case NVCBC0_CALL_MME_DATA(128):
    case NVCBC0_CALL_MME_DATA(129):
    case NVCBC0_CALL_MME_DATA(130):
    case NVCBC0_CALL_MME_DATA(131):
    case NVCBC0_CALL_MME_DATA(132):
    case NVCBC0_CALL_MME_DATA(133):
    case NVCBC0_CALL_MME_DATA(134):
    case NVCBC0_CALL_MME_DATA(135):
    case NVCBC0_CALL_MME_DATA(136):
    case NVCBC0_CALL_MME_DATA(137):
    case NVCBC0_CALL_MME_DATA(138):
    case NVCBC0_CALL_MME_DATA(139):
    case NVCBC0_CALL_MME_DATA(140):
    case NVCBC0_CALL_MME_DATA(141):
    case NVCBC0_CALL_MME_DATA(142):
    case NVCBC0_CALL_MME_DATA(143):
    case NVCBC0_CALL_MME_DATA(144):
    case NVCBC0_CALL_MME_DATA(145):
    case NVCBC0_CALL_MME_DATA(146):
    case NVCBC0_CALL_MME_DATA(147):
    case NVCBC0_CALL_MME_DATA(148):
    case NVCBC0_CALL_MME_DATA(149):
    case NVCBC0_CALL_MME_DATA(150):
    case NVCBC0_CALL_MME_DATA(151):
    case NVCBC0_CALL_MME_DATA(152):
    case NVCBC0_CALL_MME_DATA(153):
    case NVCBC0_CALL_MME_DATA(154):
    case NVCBC0_CALL_MME_DATA(155):
    case NVCBC0_CALL_MME_DATA(156):
    case NVCBC0_CALL_MME_DATA(157):
    case NVCBC0_CALL_MME_DATA(158):
    case NVCBC0_CALL_MME_DATA(159):
    case NVCBC0_CALL_MME_DATA(160):
    case NVCBC0_CALL_MME_DATA(161):
    case NVCBC0_CALL_MME_DATA(162):
    case NVCBC0_CALL_MME_DATA(163):
    case NVCBC0_CALL_MME_DATA(164):
    case NVCBC0_CALL_MME_DATA(165):
    case NVCBC0_CALL_MME_DATA(166):
    case NVCBC0_CALL_MME_DATA(167):
    case NVCBC0_CALL_MME_DATA(168):
    case NVCBC0_CALL_MME_DATA(169):
    case NVCBC0_CALL_MME_DATA(170):
    case NVCBC0_CALL_MME_DATA(171):
    case NVCBC0_CALL_MME_DATA(172):
    case NVCBC0_CALL_MME_DATA(173):
    case NVCBC0_CALL_MME_DATA(174):
    case NVCBC0_CALL_MME_DATA(175):
    case NVCBC0_CALL_MME_DATA(176):
    case NVCBC0_CALL_MME_DATA(177):
    case NVCBC0_CALL_MME_DATA(178):
    case NVCBC0_CALL_MME_DATA(179):
    case NVCBC0_CALL_MME_DATA(180):
    case NVCBC0_CALL_MME_DATA(181):
    case NVCBC0_CALL_MME_DATA(182):
    case NVCBC0_CALL_MME_DATA(183):
    case NVCBC0_CALL_MME_DATA(184):
    case NVCBC0_CALL_MME_DATA(185):
    case NVCBC0_CALL_MME_DATA(186):
    case NVCBC0_CALL_MME_DATA(187):
    case NVCBC0_CALL_MME_DATA(188):
    case NVCBC0_CALL_MME_DATA(189):
    case NVCBC0_CALL_MME_DATA(190):
    case NVCBC0_CALL_MME_DATA(191):
    case NVCBC0_CALL_MME_DATA(192):
    case NVCBC0_CALL_MME_DATA(193):
    case NVCBC0_CALL_MME_DATA(194):
    case NVCBC0_CALL_MME_DATA(195):
    case NVCBC0_CALL_MME_DATA(196):
    case NVCBC0_CALL_MME_DATA(197):
    case NVCBC0_CALL_MME_DATA(198):
    case NVCBC0_CALL_MME_DATA(199):
    case NVCBC0_CALL_MME_DATA(200):
    case NVCBC0_CALL_MME_DATA(201):
    case NVCBC0_CALL_MME_DATA(202):
    case NVCBC0_CALL_MME_DATA(203):
    case NVCBC0_CALL_MME_DATA(204):
    case NVCBC0_CALL_MME_DATA(205):
    case NVCBC0_CALL_MME_DATA(206):
    case NVCBC0_CALL_MME_DATA(207):
    case NVCBC0_CALL_MME_DATA(208):
    case NVCBC0_CALL_MME_DATA(209):
    case NVCBC0_CALL_MME_DATA(210):
    case NVCBC0_CALL_MME_DATA(211):
    case NVCBC0_CALL_MME_DATA(212):
    case NVCBC0_CALL_MME_DATA(213):
    case NVCBC0_CALL_MME_DATA(214):
    case NVCBC0_CALL_MME_DATA(215):
    case NVCBC0_CALL_MME_DATA(216):
    case NVCBC0_CALL_MME_DATA(217):
    case NVCBC0_CALL_MME_DATA(218):
    case NVCBC0_CALL_MME_DATA(219):
    case NVCBC0_CALL_MME_DATA(220):
    case NVCBC0_CALL_MME_DATA(221):
    case NVCBC0_CALL_MME_DATA(222):
    case NVCBC0_CALL_MME_DATA(223):
    case NVCBC0_CALL_MME_DATA(224):
    case NVCBC0_CALL_MME_DATA(225):
    case NVCBC0_CALL_MME_DATA(226):
    case NVCBC0_CALL_MME_DATA(227):
    case NVCBC0_CALL_MME_DATA(228):
    case NVCBC0_CALL_MME_DATA(229):
    case NVCBC0_CALL_MME_DATA(230):
    case NVCBC0_CALL_MME_DATA(231):
    case NVCBC0_CALL_MME_DATA(232):
    case NVCBC0_CALL_MME_DATA(233):
    case NVCBC0_CALL_MME_DATA(234):
    case NVCBC0_CALL_MME_DATA(235):
    case NVCBC0_CALL_MME_DATA(236):
    case NVCBC0_CALL_MME_DATA(237):
    case NVCBC0_CALL_MME_DATA(238):
    case NVCBC0_CALL_MME_DATA(239):
    case NVCBC0_CALL_MME_DATA(240):
    case NVCBC0_CALL_MME_DATA(241):
    case NVCBC0_CALL_MME_DATA(242):
    case NVCBC0_CALL_MME_DATA(243):
    case NVCBC0_CALL_MME_DATA(244):
    case NVCBC0_CALL_MME_DATA(245):
    case NVCBC0_CALL_MME_DATA(246):
    case NVCBC0_CALL_MME_DATA(247):
    case NVCBC0_CALL_MME_DATA(248):
    case NVCBC0_CALL_MME_DATA(249):
    case NVCBC0_CALL_MME_DATA(250):
    case NVCBC0_CALL_MME_DATA(251):
    case NVCBC0_CALL_MME_DATA(252):
    case NVCBC0_CALL_MME_DATA(253):
    case NVCBC0_CALL_MME_DATA(254):
    case NVCBC0_CALL_MME_DATA(255):


    return P_PARSE_NVC9C0_MTHD(idx);

            case NVCBC0_SET_NOTIFY_A:
        return "NVCBC0_SET_NOTIFY_A";
                                                                                        case NVCBC0_SET_REPORT_SEMAPHORE_ADDRESS_UPPER:
        return "NVCBC0_SET_REPORT_SEMAPHORE_ADDRESS_UPPER";
                case NVCBC0_OFFSET_OUT_UPPER:
        return "NVCBC0_OFFSET_OUT_UPPER";
                                                case NVCBC0_SET_I2M_SEMAPHORE_A:
        return "NVCBC0_SET_I2M_SEMAPHORE_A";
                                                                                                                                                                                                    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_C:
        return "NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_C";
        case NVCBC0_SET_INLINE_QMD_ADDRESS_A:
        return "NVCBC0_SET_INLINE_QMD_ADDRESS_A";
                                                                            case NVCBC0_SET_MME_MEM_ADDRESS_A:
        return "NVCBC0_SET_MME_MEM_ADDRESS_A";
                                        case NVCBC0_SET_SHADER_LOCAL_MEMORY_A:
        return "NVCBC0_SET_SHADER_LOCAL_MEMORY_A";
        case NVCBC0_SET_TEXTURE_HEADER_VERSION:
        return "NVCBC0_SET_TEXTURE_HEADER_VERSION";
            case NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_A:
        return "NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_A";
    case NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_B:
        return "NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_B";
                                                                case NVCBC0_SET_TEX_SAMPLER_POOL_A:
        return "NVCBC0_SET_TEX_SAMPLER_POOL_A";
            case NVCBC0_SET_TEX_HEADER_POOL_A:
        return "NVCBC0_SET_TEX_HEADER_POOL_A";
                                        case NVCBC0_SET_REPORT_SEMAPHORE_A:
        return "NVCBC0_SET_REPORT_SEMAPHORE_A";
                case NVCBC0_SET_TRAP_HANDLER_A:
        return "NVCBC0_SET_TRAP_HANDLER_A";
                                                                            
    default:
        return "unknown method";
    }
}

void
P_DUMP_NVCBC0_MTHD_DATA(FILE *fp, uint16_t idx, uint32_t data,
                         const char *prefix)
{
    UNUSED uint32_t parsed;
    switch (idx) {

  
        
    case NVCBC0_SET_OBJECT:

        
    case NVCBC0_NO_OPERATION:

        
    case NVCBC0_SET_NOTIFY_B:

        
    case NVCBC0_NOTIFY:

        
    case NVCBC0_WAIT_FOR_IDLE:

        
    case NVCBC0_LOAD_MME_INSTRUCTION_RAM_POINTER:

        
    case NVCBC0_LOAD_MME_INSTRUCTION_RAM:

        
    case NVCBC0_LOAD_MME_START_ADDRESS_RAM_POINTER:

        
    case NVCBC0_LOAD_MME_START_ADDRESS_RAM:

        
    case NVCBC0_SET_MME_SHADOW_RAM_CONTROL:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_A:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_B:

        
    case NVCBC0_SET_GLOBAL_RENDER_ENABLE_C:

        
    case NVCBC0_SEND_GO_IDLE:

        
    case NVCBC0_PM_TRIGGER:

        
    case NVCBC0_PM_TRIGGER_WFI:

        
    case NVCBC0_FE_ATOMIC_SEQUENCE_BEGIN:

        
    case NVCBC0_FE_ATOMIC_SEQUENCE_END:

        
    case NVCBC0_SET_INSTRUMENTATION_METHOD_HEADER:

        
    case NVCBC0_SET_INSTRUMENTATION_METHOD_DATA:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_PAYLOAD_LOWER:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_PAYLOAD_UPPER:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_ADDRESS_LOWER:

        
    case NVCBC0_REPORT_SEMAPHORE_EXECUTE:

        
    case NVCBC0_LINE_LENGTH_IN:

        
    case NVCBC0_LINE_COUNT:

        
    case NVCBC0_OFFSET_OUT:

        
    case NVCBC0_PITCH_OUT:

        
    case NVCBC0_SET_DST_BLOCK_SIZE:

        
    case NVCBC0_SET_DST_WIDTH:

        
    case NVCBC0_SET_DST_HEIGHT:

        
    case NVCBC0_SET_DST_DEPTH:

        
    case NVCBC0_SET_DST_LAYER:

        
    case NVCBC0_SET_DST_ORIGIN_BYTES_X:

        
    case NVCBC0_SET_DST_ORIGIN_SAMPLES_Y:

        
    case NVCBC0_LAUNCH_DMA:

        
    case NVCBC0_LOAD_INLINE_DATA:

        
    case NVCBC0_SET_I2M_SEMAPHORE_B:

        
    case NVCBC0_SET_I2M_SEMAPHORE_C:

        
    case NVCBC0_SET_SM_SCG_CONTROL:

        
    case NVCBC0_SET_MME_SWITCH_STATE:

        
    case NVCBC0_SET_I2M_SPARE_NOOP00:

        
    case NVCBC0_SET_I2M_SPARE_NOOP01:

        
    case NVCBC0_SET_I2M_SPARE_NOOP02:

        
    case NVCBC0_SET_I2M_SPARE_NOOP03:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_A:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_B:

        
    case NVCBC0_SET_VALID_SPAN_OVERFLOW_AREA_C:

        
    case NVCBC0_PERFMON_TRANSFER:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_BASE_A:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_BASE_B:

        
    case NVCBC0_INVALIDATE_SHADER_CACHES:

        
    case NVCBC0_SET_RESERVED_SW_METHOD00:

        
    case NVCBC0_SET_RESERVED_SW_METHOD01:

        
    case NVCBC0_SET_RESERVED_SW_METHOD02:

        
    case NVCBC0_SET_RESERVED_SW_METHOD03:

        
    case NVCBC0_SET_RESERVED_SW_METHOD04:

        
    case NVCBC0_SET_RESERVED_SW_METHOD05:

        
    case NVCBC0_SET_RESERVED_SW_METHOD06:

        
    case NVCBC0_SET_RESERVED_SW_METHOD07:

        
    case NVCBC0_INVALIDATE_TEXTURE_HEADER_CACHE_NO_WFI:

        
    case NVCBC0_SET_CWD_REF_COUNTER:

        
    case NVCBC0_SET_RESERVED_SW_METHOD08:

        
    case NVCBC0_SET_RESERVED_SW_METHOD09:

        
    case NVCBC0_SET_RESERVED_SW_METHOD10:

        
    case NVCBC0_SET_RESERVED_SW_METHOD11:

        
    case NVCBC0_SET_RESERVED_SW_METHOD12:

        
    case NVCBC0_SET_RESERVED_SW_METHOD13:

        
    case NVCBC0_SET_RESERVED_SW_METHOD14:

        
    case NVCBC0_SET_RESERVED_SW_METHOD15:

        
    case NVCBC0_SET_COMPUTE_CLASS_VERSION:

        
    case NVCBC0_CHECK_COMPUTE_CLASS_VERSION:

        
    case NVCBC0_SET_QMD_VERSION:

        
    case NVCBC0_INVALIDATE_SKED_CACHES:

        
    case NVCBC0_SET_QMD_VIRTUALIZATION_CONTROL:

        
    case NVCBC0_SET_SHADER_SHARED_MEMORY_WINDOW_A:

        
    case NVCBC0_SET_SHADER_SHARED_MEMORY_WINDOW_B:

        
    case NVCBC0_SET_CWD_SLOT_COUNT:

        
    case NVCBC0_SEND_PCAS_A:

        
    case NVCBC0_SEND_PCAS_B:

        
    case NVCBC0_SEND_SIGNALING_PCAS_B:

        
    case NVCBC0_SEND_SIGNALING_PCAS2_B:

        
    case NVCBC0_SET_SKED_CACHE_CONTROL:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_A:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_B:

        
    case NVCBC0_SET_SPA_VERSION:

        
    case NVCBC0_SET_INLINE_QMD_ADDRESS_B:

        
    case NVCBC0_LOAD_INLINE_QMD_DATA(0):
    case NVCBC0_LOAD_INLINE_QMD_DATA(1):
    case NVCBC0_LOAD_INLINE_QMD_DATA(2):
    case NVCBC0_LOAD_INLINE_QMD_DATA(3):
    case NVCBC0_LOAD_INLINE_QMD_DATA(4):
    case NVCBC0_LOAD_INLINE_QMD_DATA(5):
    case NVCBC0_LOAD_INLINE_QMD_DATA(6):
    case NVCBC0_LOAD_INLINE_QMD_DATA(7):
    case NVCBC0_LOAD_INLINE_QMD_DATA(8):
    case NVCBC0_LOAD_INLINE_QMD_DATA(9):
    case NVCBC0_LOAD_INLINE_QMD_DATA(10):
    case NVCBC0_LOAD_INLINE_QMD_DATA(11):
    case NVCBC0_LOAD_INLINE_QMD_DATA(12):
    case NVCBC0_LOAD_INLINE_QMD_DATA(13):
    case NVCBC0_LOAD_INLINE_QMD_DATA(14):
    case NVCBC0_LOAD_INLINE_QMD_DATA(15):
    case NVCBC0_LOAD_INLINE_QMD_DATA(16):
    case NVCBC0_LOAD_INLINE_QMD_DATA(17):
    case NVCBC0_LOAD_INLINE_QMD_DATA(18):
    case NVCBC0_LOAD_INLINE_QMD_DATA(19):
    case NVCBC0_LOAD_INLINE_QMD_DATA(20):
    case NVCBC0_LOAD_INLINE_QMD_DATA(21):
    case NVCBC0_LOAD_INLINE_QMD_DATA(22):
    case NVCBC0_LOAD_INLINE_QMD_DATA(23):
    case NVCBC0_LOAD_INLINE_QMD_DATA(24):
    case NVCBC0_LOAD_INLINE_QMD_DATA(25):
    case NVCBC0_LOAD_INLINE_QMD_DATA(26):
    case NVCBC0_LOAD_INLINE_QMD_DATA(27):
    case NVCBC0_LOAD_INLINE_QMD_DATA(28):
    case NVCBC0_LOAD_INLINE_QMD_DATA(29):
    case NVCBC0_LOAD_INLINE_QMD_DATA(30):
    case NVCBC0_LOAD_INLINE_QMD_DATA(31):
    case NVCBC0_LOAD_INLINE_QMD_DATA(32):
    case NVCBC0_LOAD_INLINE_QMD_DATA(33):
    case NVCBC0_LOAD_INLINE_QMD_DATA(34):
    case NVCBC0_LOAD_INLINE_QMD_DATA(35):
    case NVCBC0_LOAD_INLINE_QMD_DATA(36):
    case NVCBC0_LOAD_INLINE_QMD_DATA(37):
    case NVCBC0_LOAD_INLINE_QMD_DATA(38):
    case NVCBC0_LOAD_INLINE_QMD_DATA(39):
    case NVCBC0_LOAD_INLINE_QMD_DATA(40):
    case NVCBC0_LOAD_INLINE_QMD_DATA(41):
    case NVCBC0_LOAD_INLINE_QMD_DATA(42):
    case NVCBC0_LOAD_INLINE_QMD_DATA(43):
    case NVCBC0_LOAD_INLINE_QMD_DATA(44):
    case NVCBC0_LOAD_INLINE_QMD_DATA(45):
    case NVCBC0_LOAD_INLINE_QMD_DATA(46):
    case NVCBC0_LOAD_INLINE_QMD_DATA(47):
    case NVCBC0_LOAD_INLINE_QMD_DATA(48):
    case NVCBC0_LOAD_INLINE_QMD_DATA(49):
    case NVCBC0_LOAD_INLINE_QMD_DATA(50):
    case NVCBC0_LOAD_INLINE_QMD_DATA(51):
    case NVCBC0_LOAD_INLINE_QMD_DATA(52):
    case NVCBC0_LOAD_INLINE_QMD_DATA(53):
    case NVCBC0_LOAD_INLINE_QMD_DATA(54):
    case NVCBC0_LOAD_INLINE_QMD_DATA(55):
    case NVCBC0_LOAD_INLINE_QMD_DATA(56):
    case NVCBC0_LOAD_INLINE_QMD_DATA(57):
    case NVCBC0_LOAD_INLINE_QMD_DATA(58):
    case NVCBC0_LOAD_INLINE_QMD_DATA(59):
    case NVCBC0_LOAD_INLINE_QMD_DATA(60):
    case NVCBC0_LOAD_INLINE_QMD_DATA(61):
    case NVCBC0_LOAD_INLINE_QMD_DATA(62):
    case NVCBC0_LOAD_INLINE_QMD_DATA(63):

        
    case NVCBC0_SET_FALCON00:

        
    case NVCBC0_SET_FALCON01:

        
    case NVCBC0_SET_FALCON02:

        
    case NVCBC0_SET_FALCON03:

        
    case NVCBC0_SET_FALCON04:

        
    case NVCBC0_SET_FALCON05:

        
    case NVCBC0_SET_FALCON06:

        
    case NVCBC0_SET_FALCON07:

        
    case NVCBC0_SET_FALCON08:

        
    case NVCBC0_SET_FALCON09:

        
    case NVCBC0_SET_FALCON10:

        
    case NVCBC0_SET_FALCON11:

        
    case NVCBC0_SET_FALCON12:

        
    case NVCBC0_SET_FALCON13:

        
    case NVCBC0_SET_FALCON14:

        
    case NVCBC0_SET_FALCON15:

        
    case NVCBC0_SET_MME_MEM_ADDRESS_B:

        
    case NVCBC0_SET_MME_DATA_RAM_ADDRESS:

        
    case NVCBC0_MME_DMA_READ:

        
    case NVCBC0_MME_DMA_READ_FIFOED:

        
    case NVCBC0_MME_DMA_WRITE:

        
    case NVCBC0_MME_DMA_REDUCTION:

        
    case NVCBC0_MME_DMA_SYSMEMBAR:

        
    case NVCBC0_MME_DMA_SYNC:

        
    case NVCBC0_SET_MME_DATA_FIFO_CONFIG:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_B:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_WINDOW_A:

        
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_WINDOW_B:

        
    case NVCBC0_THROTTLE_SM:

        
    case NVCBC0_SET_SHADER_CACHE_CONTROL:

        
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(0):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(1):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(2):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(3):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(4):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(5):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(6):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(7):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(8):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(9):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(10):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(11):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(12):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(13):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(14):
    case NVCBC0_SET_SCG_COMPUTE_SCHEDULING_PARAMETERS(15):

        
    case NVCBC0_SET_SM_TIMEOUT_INTERVAL:

        
    case NVCBC0_MME_DMA_WRITE_METHOD_BARRIER:

        
    case NVCBC0_INVALIDATE_TEXTURE_DATA_CACHE_NO_WFI:

        
    case NVCBC0_ACTIVATE_PERF_SETTINGS_FOR_COMPUTE_CONTEXT:

        
    case NVCBC0_INVALIDATE_SAMPLER_CACHE:

        
    case NVCBC0_INVALIDATE_TEXTURE_HEADER_CACHE:

        
    case NVCBC0_INVALIDATE_TEXTURE_DATA_CACHE:

        
    case NVCBC0_INVALIDATE_SAMPLER_CACHE_NO_WFI:

        
    case NVCBC0_SET_SHADER_EXCEPTIONS:

        
    case NVCBC0_SET_RENDER_ENABLE_A:

        
    case NVCBC0_SET_RENDER_ENABLE_B:

        
    case NVCBC0_SET_RENDER_ENABLE_C:

        
    case NVCBC0_SET_TEX_SAMPLER_POOL_B:

        
    case NVCBC0_SET_TEX_SAMPLER_POOL_C:

        
    case NVCBC0_SET_TEX_HEADER_POOL_B:

        
    case NVCBC0_SET_TEX_HEADER_POOL_C:

        
    case NVCBC0_INVALIDATE_SHADER_CACHES_NO_WFI:

        
    case NVCBC0_SET_RENDER_ENABLE_OVERRIDE:

        
    case NVCBC0_PIPE_NOP:

        
    case NVCBC0_SET_SPARE00:

        
    case NVCBC0_SET_SPARE01:

        
    case NVCBC0_SET_SPARE02:

        
    case NVCBC0_SET_SPARE03:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_B:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_C:

        
    case NVCBC0_SET_REPORT_SEMAPHORE_D:

        
    case NVCBC0_SET_TRAP_HANDLER_B:

        
    case NVCBC0_SET_BINDLESS_TEXTURE:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_SNAPSHOT_COUNTER_VALUE_UPPER(7):

        
    case NVCBC0_ENABLE_SHADER_PERFORMANCE_SNAPSHOT_COUNTER:

        
    case NVCBC0_DISABLE_SHADER_PERFORMANCE_SNAPSHOT_COUNTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE_UPPER(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_VALUE(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_EVENT(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(0):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(1):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(2):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(3):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(4):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(5):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(6):
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(7):

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_TRAP_CONTROL:

        
    case NVCBC0_START_SHADER_PERFORMANCE_COUNTER:

        
    case NVCBC0_STOP_SHADER_PERFORMANCE_COUNTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_SCTL_FILTER:

        
    case NVCBC0_SET_SHADER_PERFORMANCE_COUNTER_CORE_MIO_FILTER:

        
    case NVCBC0_SET_MME_SHADOW_SCRATCH(0):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(1):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(2):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(3):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(4):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(5):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(6):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(7):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(8):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(9):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(10):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(11):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(12):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(13):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(14):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(15):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(16):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(17):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(18):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(19):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(20):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(21):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(22):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(23):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(24):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(25):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(26):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(27):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(28):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(29):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(30):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(31):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(32):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(33):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(34):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(35):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(36):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(37):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(38):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(39):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(40):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(41):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(42):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(43):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(44):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(45):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(46):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(47):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(48):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(49):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(50):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(51):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(52):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(53):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(54):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(55):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(56):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(57):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(58):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(59):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(60):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(61):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(62):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(63):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(64):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(65):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(66):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(67):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(68):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(69):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(70):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(71):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(72):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(73):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(74):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(75):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(76):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(77):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(78):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(79):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(80):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(81):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(82):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(83):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(84):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(85):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(86):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(87):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(88):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(89):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(90):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(91):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(92):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(93):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(94):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(95):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(96):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(97):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(98):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(99):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(100):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(101):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(102):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(103):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(104):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(105):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(106):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(107):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(108):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(109):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(110):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(111):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(112):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(113):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(114):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(115):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(116):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(117):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(118):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(119):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(120):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(121):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(122):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(123):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(124):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(125):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(126):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(127):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(128):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(129):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(130):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(131):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(132):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(133):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(134):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(135):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(136):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(137):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(138):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(139):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(140):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(141):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(142):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(143):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(144):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(145):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(146):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(147):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(148):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(149):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(150):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(151):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(152):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(153):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(154):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(155):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(156):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(157):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(158):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(159):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(160):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(161):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(162):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(163):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(164):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(165):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(166):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(167):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(168):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(169):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(170):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(171):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(172):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(173):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(174):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(175):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(176):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(177):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(178):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(179):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(180):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(181):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(182):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(183):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(184):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(185):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(186):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(187):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(188):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(189):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(190):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(191):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(192):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(193):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(194):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(195):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(196):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(197):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(198):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(199):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(200):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(201):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(202):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(203):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(204):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(205):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(206):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(207):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(208):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(209):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(210):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(211):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(212):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(213):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(214):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(215):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(216):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(217):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(218):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(219):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(220):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(221):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(222):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(223):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(224):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(225):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(226):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(227):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(228):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(229):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(230):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(231):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(232):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(233):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(234):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(235):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(236):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(237):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(238):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(239):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(240):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(241):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(242):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(243):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(244):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(245):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(246):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(247):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(248):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(249):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(250):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(251):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(252):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(253):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(254):
    case NVCBC0_SET_MME_SHADOW_SCRATCH(255):

        
    case NVCBC0_CALL_MME_MACRO(0):
    case NVCBC0_CALL_MME_MACRO(1):
    case NVCBC0_CALL_MME_MACRO(2):
    case NVCBC0_CALL_MME_MACRO(3):
    case NVCBC0_CALL_MME_MACRO(4):
    case NVCBC0_CALL_MME_MACRO(5):
    case NVCBC0_CALL_MME_MACRO(6):
    case NVCBC0_CALL_MME_MACRO(7):
    case NVCBC0_CALL_MME_MACRO(8):
    case NVCBC0_CALL_MME_MACRO(9):
    case NVCBC0_CALL_MME_MACRO(10):
    case NVCBC0_CALL_MME_MACRO(11):
    case NVCBC0_CALL_MME_MACRO(12):
    case NVCBC0_CALL_MME_MACRO(13):
    case NVCBC0_CALL_MME_MACRO(14):
    case NVCBC0_CALL_MME_MACRO(15):
    case NVCBC0_CALL_MME_MACRO(16):
    case NVCBC0_CALL_MME_MACRO(17):
    case NVCBC0_CALL_MME_MACRO(18):
    case NVCBC0_CALL_MME_MACRO(19):
    case NVCBC0_CALL_MME_MACRO(20):
    case NVCBC0_CALL_MME_MACRO(21):
    case NVCBC0_CALL_MME_MACRO(22):
    case NVCBC0_CALL_MME_MACRO(23):
    case NVCBC0_CALL_MME_MACRO(24):
    case NVCBC0_CALL_MME_MACRO(25):
    case NVCBC0_CALL_MME_MACRO(26):
    case NVCBC0_CALL_MME_MACRO(27):
    case NVCBC0_CALL_MME_MACRO(28):
    case NVCBC0_CALL_MME_MACRO(29):
    case NVCBC0_CALL_MME_MACRO(30):
    case NVCBC0_CALL_MME_MACRO(31):
    case NVCBC0_CALL_MME_MACRO(32):
    case NVCBC0_CALL_MME_MACRO(33):
    case NVCBC0_CALL_MME_MACRO(34):
    case NVCBC0_CALL_MME_MACRO(35):
    case NVCBC0_CALL_MME_MACRO(36):
    case NVCBC0_CALL_MME_MACRO(37):
    case NVCBC0_CALL_MME_MACRO(38):
    case NVCBC0_CALL_MME_MACRO(39):
    case NVCBC0_CALL_MME_MACRO(40):
    case NVCBC0_CALL_MME_MACRO(41):
    case NVCBC0_CALL_MME_MACRO(42):
    case NVCBC0_CALL_MME_MACRO(43):
    case NVCBC0_CALL_MME_MACRO(44):
    case NVCBC0_CALL_MME_MACRO(45):
    case NVCBC0_CALL_MME_MACRO(46):
    case NVCBC0_CALL_MME_MACRO(47):
    case NVCBC0_CALL_MME_MACRO(48):
    case NVCBC0_CALL_MME_MACRO(49):
    case NVCBC0_CALL_MME_MACRO(50):
    case NVCBC0_CALL_MME_MACRO(51):
    case NVCBC0_CALL_MME_MACRO(52):
    case NVCBC0_CALL_MME_MACRO(53):
    case NVCBC0_CALL_MME_MACRO(54):
    case NVCBC0_CALL_MME_MACRO(55):
    case NVCBC0_CALL_MME_MACRO(56):
    case NVCBC0_CALL_MME_MACRO(57):
    case NVCBC0_CALL_MME_MACRO(58):
    case NVCBC0_CALL_MME_MACRO(59):
    case NVCBC0_CALL_MME_MACRO(60):
    case NVCBC0_CALL_MME_MACRO(61):
    case NVCBC0_CALL_MME_MACRO(62):
    case NVCBC0_CALL_MME_MACRO(63):
    case NVCBC0_CALL_MME_MACRO(64):
    case NVCBC0_CALL_MME_MACRO(65):
    case NVCBC0_CALL_MME_MACRO(66):
    case NVCBC0_CALL_MME_MACRO(67):
    case NVCBC0_CALL_MME_MACRO(68):
    case NVCBC0_CALL_MME_MACRO(69):
    case NVCBC0_CALL_MME_MACRO(70):
    case NVCBC0_CALL_MME_MACRO(71):
    case NVCBC0_CALL_MME_MACRO(72):
    case NVCBC0_CALL_MME_MACRO(73):
    case NVCBC0_CALL_MME_MACRO(74):
    case NVCBC0_CALL_MME_MACRO(75):
    case NVCBC0_CALL_MME_MACRO(76):
    case NVCBC0_CALL_MME_MACRO(77):
    case NVCBC0_CALL_MME_MACRO(78):
    case NVCBC0_CALL_MME_MACRO(79):
    case NVCBC0_CALL_MME_MACRO(80):
    case NVCBC0_CALL_MME_MACRO(81):
    case NVCBC0_CALL_MME_MACRO(82):
    case NVCBC0_CALL_MME_MACRO(83):
    case NVCBC0_CALL_MME_MACRO(84):
    case NVCBC0_CALL_MME_MACRO(85):
    case NVCBC0_CALL_MME_MACRO(86):
    case NVCBC0_CALL_MME_MACRO(87):
    case NVCBC0_CALL_MME_MACRO(88):
    case NVCBC0_CALL_MME_MACRO(89):
    case NVCBC0_CALL_MME_MACRO(90):
    case NVCBC0_CALL_MME_MACRO(91):
    case NVCBC0_CALL_MME_MACRO(92):
    case NVCBC0_CALL_MME_MACRO(93):
    case NVCBC0_CALL_MME_MACRO(94):
    case NVCBC0_CALL_MME_MACRO(95):
    case NVCBC0_CALL_MME_MACRO(96):
    case NVCBC0_CALL_MME_MACRO(97):
    case NVCBC0_CALL_MME_MACRO(98):
    case NVCBC0_CALL_MME_MACRO(99):
    case NVCBC0_CALL_MME_MACRO(100):
    case NVCBC0_CALL_MME_MACRO(101):
    case NVCBC0_CALL_MME_MACRO(102):
    case NVCBC0_CALL_MME_MACRO(103):
    case NVCBC0_CALL_MME_MACRO(104):
    case NVCBC0_CALL_MME_MACRO(105):
    case NVCBC0_CALL_MME_MACRO(106):
    case NVCBC0_CALL_MME_MACRO(107):
    case NVCBC0_CALL_MME_MACRO(108):
    case NVCBC0_CALL_MME_MACRO(109):
    case NVCBC0_CALL_MME_MACRO(110):
    case NVCBC0_CALL_MME_MACRO(111):
    case NVCBC0_CALL_MME_MACRO(112):
    case NVCBC0_CALL_MME_MACRO(113):
    case NVCBC0_CALL_MME_MACRO(114):
    case NVCBC0_CALL_MME_MACRO(115):
    case NVCBC0_CALL_MME_MACRO(116):
    case NVCBC0_CALL_MME_MACRO(117):
    case NVCBC0_CALL_MME_MACRO(118):
    case NVCBC0_CALL_MME_MACRO(119):
    case NVCBC0_CALL_MME_MACRO(120):
    case NVCBC0_CALL_MME_MACRO(121):
    case NVCBC0_CALL_MME_MACRO(122):
    case NVCBC0_CALL_MME_MACRO(123):
    case NVCBC0_CALL_MME_MACRO(124):
    case NVCBC0_CALL_MME_MACRO(125):
    case NVCBC0_CALL_MME_MACRO(126):
    case NVCBC0_CALL_MME_MACRO(127):
    case NVCBC0_CALL_MME_MACRO(128):
    case NVCBC0_CALL_MME_MACRO(129):
    case NVCBC0_CALL_MME_MACRO(130):
    case NVCBC0_CALL_MME_MACRO(131):
    case NVCBC0_CALL_MME_MACRO(132):
    case NVCBC0_CALL_MME_MACRO(133):
    case NVCBC0_CALL_MME_MACRO(134):
    case NVCBC0_CALL_MME_MACRO(135):
    case NVCBC0_CALL_MME_MACRO(136):
    case NVCBC0_CALL_MME_MACRO(137):
    case NVCBC0_CALL_MME_MACRO(138):
    case NVCBC0_CALL_MME_MACRO(139):
    case NVCBC0_CALL_MME_MACRO(140):
    case NVCBC0_CALL_MME_MACRO(141):
    case NVCBC0_CALL_MME_MACRO(142):
    case NVCBC0_CALL_MME_MACRO(143):
    case NVCBC0_CALL_MME_MACRO(144):
    case NVCBC0_CALL_MME_MACRO(145):
    case NVCBC0_CALL_MME_MACRO(146):
    case NVCBC0_CALL_MME_MACRO(147):
    case NVCBC0_CALL_MME_MACRO(148):
    case NVCBC0_CALL_MME_MACRO(149):
    case NVCBC0_CALL_MME_MACRO(150):
    case NVCBC0_CALL_MME_MACRO(151):
    case NVCBC0_CALL_MME_MACRO(152):
    case NVCBC0_CALL_MME_MACRO(153):
    case NVCBC0_CALL_MME_MACRO(154):
    case NVCBC0_CALL_MME_MACRO(155):
    case NVCBC0_CALL_MME_MACRO(156):
    case NVCBC0_CALL_MME_MACRO(157):
    case NVCBC0_CALL_MME_MACRO(158):
    case NVCBC0_CALL_MME_MACRO(159):
    case NVCBC0_CALL_MME_MACRO(160):
    case NVCBC0_CALL_MME_MACRO(161):
    case NVCBC0_CALL_MME_MACRO(162):
    case NVCBC0_CALL_MME_MACRO(163):
    case NVCBC0_CALL_MME_MACRO(164):
    case NVCBC0_CALL_MME_MACRO(165):
    case NVCBC0_CALL_MME_MACRO(166):
    case NVCBC0_CALL_MME_MACRO(167):
    case NVCBC0_CALL_MME_MACRO(168):
    case NVCBC0_CALL_MME_MACRO(169):
    case NVCBC0_CALL_MME_MACRO(170):
    case NVCBC0_CALL_MME_MACRO(171):
    case NVCBC0_CALL_MME_MACRO(172):
    case NVCBC0_CALL_MME_MACRO(173):
    case NVCBC0_CALL_MME_MACRO(174):
    case NVCBC0_CALL_MME_MACRO(175):
    case NVCBC0_CALL_MME_MACRO(176):
    case NVCBC0_CALL_MME_MACRO(177):
    case NVCBC0_CALL_MME_MACRO(178):
    case NVCBC0_CALL_MME_MACRO(179):
    case NVCBC0_CALL_MME_MACRO(180):
    case NVCBC0_CALL_MME_MACRO(181):
    case NVCBC0_CALL_MME_MACRO(182):
    case NVCBC0_CALL_MME_MACRO(183):
    case NVCBC0_CALL_MME_MACRO(184):
    case NVCBC0_CALL_MME_MACRO(185):
    case NVCBC0_CALL_MME_MACRO(186):
    case NVCBC0_CALL_MME_MACRO(187):
    case NVCBC0_CALL_MME_MACRO(188):
    case NVCBC0_CALL_MME_MACRO(189):
    case NVCBC0_CALL_MME_MACRO(190):
    case NVCBC0_CALL_MME_MACRO(191):
    case NVCBC0_CALL_MME_MACRO(192):
    case NVCBC0_CALL_MME_MACRO(193):
    case NVCBC0_CALL_MME_MACRO(194):
    case NVCBC0_CALL_MME_MACRO(195):
    case NVCBC0_CALL_MME_MACRO(196):
    case NVCBC0_CALL_MME_MACRO(197):
    case NVCBC0_CALL_MME_MACRO(198):
    case NVCBC0_CALL_MME_MACRO(199):
    case NVCBC0_CALL_MME_MACRO(200):
    case NVCBC0_CALL_MME_MACRO(201):
    case NVCBC0_CALL_MME_MACRO(202):
    case NVCBC0_CALL_MME_MACRO(203):
    case NVCBC0_CALL_MME_MACRO(204):
    case NVCBC0_CALL_MME_MACRO(205):
    case NVCBC0_CALL_MME_MACRO(206):
    case NVCBC0_CALL_MME_MACRO(207):
    case NVCBC0_CALL_MME_MACRO(208):
    case NVCBC0_CALL_MME_MACRO(209):
    case NVCBC0_CALL_MME_MACRO(210):
    case NVCBC0_CALL_MME_MACRO(211):
    case NVCBC0_CALL_MME_MACRO(212):
    case NVCBC0_CALL_MME_MACRO(213):
    case NVCBC0_CALL_MME_MACRO(214):
    case NVCBC0_CALL_MME_MACRO(215):
    case NVCBC0_CALL_MME_MACRO(216):
    case NVCBC0_CALL_MME_MACRO(217):
    case NVCBC0_CALL_MME_MACRO(218):
    case NVCBC0_CALL_MME_MACRO(219):
    case NVCBC0_CALL_MME_MACRO(220):
    case NVCBC0_CALL_MME_MACRO(221):
    case NVCBC0_CALL_MME_MACRO(222):
    case NVCBC0_CALL_MME_MACRO(223):
    case NVCBC0_CALL_MME_MACRO(224):
    case NVCBC0_CALL_MME_MACRO(225):
    case NVCBC0_CALL_MME_MACRO(226):
    case NVCBC0_CALL_MME_MACRO(227):
    case NVCBC0_CALL_MME_MACRO(228):
    case NVCBC0_CALL_MME_MACRO(229):
    case NVCBC0_CALL_MME_MACRO(230):
    case NVCBC0_CALL_MME_MACRO(231):
    case NVCBC0_CALL_MME_MACRO(232):
    case NVCBC0_CALL_MME_MACRO(233):
    case NVCBC0_CALL_MME_MACRO(234):
    case NVCBC0_CALL_MME_MACRO(235):
    case NVCBC0_CALL_MME_MACRO(236):
    case NVCBC0_CALL_MME_MACRO(237):
    case NVCBC0_CALL_MME_MACRO(238):
    case NVCBC0_CALL_MME_MACRO(239):
    case NVCBC0_CALL_MME_MACRO(240):
    case NVCBC0_CALL_MME_MACRO(241):
    case NVCBC0_CALL_MME_MACRO(242):
    case NVCBC0_CALL_MME_MACRO(243):
    case NVCBC0_CALL_MME_MACRO(244):
    case NVCBC0_CALL_MME_MACRO(245):
    case NVCBC0_CALL_MME_MACRO(246):
    case NVCBC0_CALL_MME_MACRO(247):
    case NVCBC0_CALL_MME_MACRO(248):
    case NVCBC0_CALL_MME_MACRO(249):
    case NVCBC0_CALL_MME_MACRO(250):
    case NVCBC0_CALL_MME_MACRO(251):
    case NVCBC0_CALL_MME_MACRO(252):
    case NVCBC0_CALL_MME_MACRO(253):
    case NVCBC0_CALL_MME_MACRO(254):
    case NVCBC0_CALL_MME_MACRO(255):

        
    case NVCBC0_CALL_MME_DATA(0):
    case NVCBC0_CALL_MME_DATA(1):
    case NVCBC0_CALL_MME_DATA(2):
    case NVCBC0_CALL_MME_DATA(3):
    case NVCBC0_CALL_MME_DATA(4):
    case NVCBC0_CALL_MME_DATA(5):
    case NVCBC0_CALL_MME_DATA(6):
    case NVCBC0_CALL_MME_DATA(7):
    case NVCBC0_CALL_MME_DATA(8):
    case NVCBC0_CALL_MME_DATA(9):
    case NVCBC0_CALL_MME_DATA(10):
    case NVCBC0_CALL_MME_DATA(11):
    case NVCBC0_CALL_MME_DATA(12):
    case NVCBC0_CALL_MME_DATA(13):
    case NVCBC0_CALL_MME_DATA(14):
    case NVCBC0_CALL_MME_DATA(15):
    case NVCBC0_CALL_MME_DATA(16):
    case NVCBC0_CALL_MME_DATA(17):
    case NVCBC0_CALL_MME_DATA(18):
    case NVCBC0_CALL_MME_DATA(19):
    case NVCBC0_CALL_MME_DATA(20):
    case NVCBC0_CALL_MME_DATA(21):
    case NVCBC0_CALL_MME_DATA(22):
    case NVCBC0_CALL_MME_DATA(23):
    case NVCBC0_CALL_MME_DATA(24):
    case NVCBC0_CALL_MME_DATA(25):
    case NVCBC0_CALL_MME_DATA(26):
    case NVCBC0_CALL_MME_DATA(27):
    case NVCBC0_CALL_MME_DATA(28):
    case NVCBC0_CALL_MME_DATA(29):
    case NVCBC0_CALL_MME_DATA(30):
    case NVCBC0_CALL_MME_DATA(31):
    case NVCBC0_CALL_MME_DATA(32):
    case NVCBC0_CALL_MME_DATA(33):
    case NVCBC0_CALL_MME_DATA(34):
    case NVCBC0_CALL_MME_DATA(35):
    case NVCBC0_CALL_MME_DATA(36):
    case NVCBC0_CALL_MME_DATA(37):
    case NVCBC0_CALL_MME_DATA(38):
    case NVCBC0_CALL_MME_DATA(39):
    case NVCBC0_CALL_MME_DATA(40):
    case NVCBC0_CALL_MME_DATA(41):
    case NVCBC0_CALL_MME_DATA(42):
    case NVCBC0_CALL_MME_DATA(43):
    case NVCBC0_CALL_MME_DATA(44):
    case NVCBC0_CALL_MME_DATA(45):
    case NVCBC0_CALL_MME_DATA(46):
    case NVCBC0_CALL_MME_DATA(47):
    case NVCBC0_CALL_MME_DATA(48):
    case NVCBC0_CALL_MME_DATA(49):
    case NVCBC0_CALL_MME_DATA(50):
    case NVCBC0_CALL_MME_DATA(51):
    case NVCBC0_CALL_MME_DATA(52):
    case NVCBC0_CALL_MME_DATA(53):
    case NVCBC0_CALL_MME_DATA(54):
    case NVCBC0_CALL_MME_DATA(55):
    case NVCBC0_CALL_MME_DATA(56):
    case NVCBC0_CALL_MME_DATA(57):
    case NVCBC0_CALL_MME_DATA(58):
    case NVCBC0_CALL_MME_DATA(59):
    case NVCBC0_CALL_MME_DATA(60):
    case NVCBC0_CALL_MME_DATA(61):
    case NVCBC0_CALL_MME_DATA(62):
    case NVCBC0_CALL_MME_DATA(63):
    case NVCBC0_CALL_MME_DATA(64):
    case NVCBC0_CALL_MME_DATA(65):
    case NVCBC0_CALL_MME_DATA(66):
    case NVCBC0_CALL_MME_DATA(67):
    case NVCBC0_CALL_MME_DATA(68):
    case NVCBC0_CALL_MME_DATA(69):
    case NVCBC0_CALL_MME_DATA(70):
    case NVCBC0_CALL_MME_DATA(71):
    case NVCBC0_CALL_MME_DATA(72):
    case NVCBC0_CALL_MME_DATA(73):
    case NVCBC0_CALL_MME_DATA(74):
    case NVCBC0_CALL_MME_DATA(75):
    case NVCBC0_CALL_MME_DATA(76):
    case NVCBC0_CALL_MME_DATA(77):
    case NVCBC0_CALL_MME_DATA(78):
    case NVCBC0_CALL_MME_DATA(79):
    case NVCBC0_CALL_MME_DATA(80):
    case NVCBC0_CALL_MME_DATA(81):
    case NVCBC0_CALL_MME_DATA(82):
    case NVCBC0_CALL_MME_DATA(83):
    case NVCBC0_CALL_MME_DATA(84):
    case NVCBC0_CALL_MME_DATA(85):
    case NVCBC0_CALL_MME_DATA(86):
    case NVCBC0_CALL_MME_DATA(87):
    case NVCBC0_CALL_MME_DATA(88):
    case NVCBC0_CALL_MME_DATA(89):
    case NVCBC0_CALL_MME_DATA(90):
    case NVCBC0_CALL_MME_DATA(91):
    case NVCBC0_CALL_MME_DATA(92):
    case NVCBC0_CALL_MME_DATA(93):
    case NVCBC0_CALL_MME_DATA(94):
    case NVCBC0_CALL_MME_DATA(95):
    case NVCBC0_CALL_MME_DATA(96):
    case NVCBC0_CALL_MME_DATA(97):
    case NVCBC0_CALL_MME_DATA(98):
    case NVCBC0_CALL_MME_DATA(99):
    case NVCBC0_CALL_MME_DATA(100):
    case NVCBC0_CALL_MME_DATA(101):
    case NVCBC0_CALL_MME_DATA(102):
    case NVCBC0_CALL_MME_DATA(103):
    case NVCBC0_CALL_MME_DATA(104):
    case NVCBC0_CALL_MME_DATA(105):
    case NVCBC0_CALL_MME_DATA(106):
    case NVCBC0_CALL_MME_DATA(107):
    case NVCBC0_CALL_MME_DATA(108):
    case NVCBC0_CALL_MME_DATA(109):
    case NVCBC0_CALL_MME_DATA(110):
    case NVCBC0_CALL_MME_DATA(111):
    case NVCBC0_CALL_MME_DATA(112):
    case NVCBC0_CALL_MME_DATA(113):
    case NVCBC0_CALL_MME_DATA(114):
    case NVCBC0_CALL_MME_DATA(115):
    case NVCBC0_CALL_MME_DATA(116):
    case NVCBC0_CALL_MME_DATA(117):
    case NVCBC0_CALL_MME_DATA(118):
    case NVCBC0_CALL_MME_DATA(119):
    case NVCBC0_CALL_MME_DATA(120):
    case NVCBC0_CALL_MME_DATA(121):
    case NVCBC0_CALL_MME_DATA(122):
    case NVCBC0_CALL_MME_DATA(123):
    case NVCBC0_CALL_MME_DATA(124):
    case NVCBC0_CALL_MME_DATA(125):
    case NVCBC0_CALL_MME_DATA(126):
    case NVCBC0_CALL_MME_DATA(127):
    case NVCBC0_CALL_MME_DATA(128):
    case NVCBC0_CALL_MME_DATA(129):
    case NVCBC0_CALL_MME_DATA(130):
    case NVCBC0_CALL_MME_DATA(131):
    case NVCBC0_CALL_MME_DATA(132):
    case NVCBC0_CALL_MME_DATA(133):
    case NVCBC0_CALL_MME_DATA(134):
    case NVCBC0_CALL_MME_DATA(135):
    case NVCBC0_CALL_MME_DATA(136):
    case NVCBC0_CALL_MME_DATA(137):
    case NVCBC0_CALL_MME_DATA(138):
    case NVCBC0_CALL_MME_DATA(139):
    case NVCBC0_CALL_MME_DATA(140):
    case NVCBC0_CALL_MME_DATA(141):
    case NVCBC0_CALL_MME_DATA(142):
    case NVCBC0_CALL_MME_DATA(143):
    case NVCBC0_CALL_MME_DATA(144):
    case NVCBC0_CALL_MME_DATA(145):
    case NVCBC0_CALL_MME_DATA(146):
    case NVCBC0_CALL_MME_DATA(147):
    case NVCBC0_CALL_MME_DATA(148):
    case NVCBC0_CALL_MME_DATA(149):
    case NVCBC0_CALL_MME_DATA(150):
    case NVCBC0_CALL_MME_DATA(151):
    case NVCBC0_CALL_MME_DATA(152):
    case NVCBC0_CALL_MME_DATA(153):
    case NVCBC0_CALL_MME_DATA(154):
    case NVCBC0_CALL_MME_DATA(155):
    case NVCBC0_CALL_MME_DATA(156):
    case NVCBC0_CALL_MME_DATA(157):
    case NVCBC0_CALL_MME_DATA(158):
    case NVCBC0_CALL_MME_DATA(159):
    case NVCBC0_CALL_MME_DATA(160):
    case NVCBC0_CALL_MME_DATA(161):
    case NVCBC0_CALL_MME_DATA(162):
    case NVCBC0_CALL_MME_DATA(163):
    case NVCBC0_CALL_MME_DATA(164):
    case NVCBC0_CALL_MME_DATA(165):
    case NVCBC0_CALL_MME_DATA(166):
    case NVCBC0_CALL_MME_DATA(167):
    case NVCBC0_CALL_MME_DATA(168):
    case NVCBC0_CALL_MME_DATA(169):
    case NVCBC0_CALL_MME_DATA(170):
    case NVCBC0_CALL_MME_DATA(171):
    case NVCBC0_CALL_MME_DATA(172):
    case NVCBC0_CALL_MME_DATA(173):
    case NVCBC0_CALL_MME_DATA(174):
    case NVCBC0_CALL_MME_DATA(175):
    case NVCBC0_CALL_MME_DATA(176):
    case NVCBC0_CALL_MME_DATA(177):
    case NVCBC0_CALL_MME_DATA(178):
    case NVCBC0_CALL_MME_DATA(179):
    case NVCBC0_CALL_MME_DATA(180):
    case NVCBC0_CALL_MME_DATA(181):
    case NVCBC0_CALL_MME_DATA(182):
    case NVCBC0_CALL_MME_DATA(183):
    case NVCBC0_CALL_MME_DATA(184):
    case NVCBC0_CALL_MME_DATA(185):
    case NVCBC0_CALL_MME_DATA(186):
    case NVCBC0_CALL_MME_DATA(187):
    case NVCBC0_CALL_MME_DATA(188):
    case NVCBC0_CALL_MME_DATA(189):
    case NVCBC0_CALL_MME_DATA(190):
    case NVCBC0_CALL_MME_DATA(191):
    case NVCBC0_CALL_MME_DATA(192):
    case NVCBC0_CALL_MME_DATA(193):
    case NVCBC0_CALL_MME_DATA(194):
    case NVCBC0_CALL_MME_DATA(195):
    case NVCBC0_CALL_MME_DATA(196):
    case NVCBC0_CALL_MME_DATA(197):
    case NVCBC0_CALL_MME_DATA(198):
    case NVCBC0_CALL_MME_DATA(199):
    case NVCBC0_CALL_MME_DATA(200):
    case NVCBC0_CALL_MME_DATA(201):
    case NVCBC0_CALL_MME_DATA(202):
    case NVCBC0_CALL_MME_DATA(203):
    case NVCBC0_CALL_MME_DATA(204):
    case NVCBC0_CALL_MME_DATA(205):
    case NVCBC0_CALL_MME_DATA(206):
    case NVCBC0_CALL_MME_DATA(207):
    case NVCBC0_CALL_MME_DATA(208):
    case NVCBC0_CALL_MME_DATA(209):
    case NVCBC0_CALL_MME_DATA(210):
    case NVCBC0_CALL_MME_DATA(211):
    case NVCBC0_CALL_MME_DATA(212):
    case NVCBC0_CALL_MME_DATA(213):
    case NVCBC0_CALL_MME_DATA(214):
    case NVCBC0_CALL_MME_DATA(215):
    case NVCBC0_CALL_MME_DATA(216):
    case NVCBC0_CALL_MME_DATA(217):
    case NVCBC0_CALL_MME_DATA(218):
    case NVCBC0_CALL_MME_DATA(219):
    case NVCBC0_CALL_MME_DATA(220):
    case NVCBC0_CALL_MME_DATA(221):
    case NVCBC0_CALL_MME_DATA(222):
    case NVCBC0_CALL_MME_DATA(223):
    case NVCBC0_CALL_MME_DATA(224):
    case NVCBC0_CALL_MME_DATA(225):
    case NVCBC0_CALL_MME_DATA(226):
    case NVCBC0_CALL_MME_DATA(227):
    case NVCBC0_CALL_MME_DATA(228):
    case NVCBC0_CALL_MME_DATA(229):
    case NVCBC0_CALL_MME_DATA(230):
    case NVCBC0_CALL_MME_DATA(231):
    case NVCBC0_CALL_MME_DATA(232):
    case NVCBC0_CALL_MME_DATA(233):
    case NVCBC0_CALL_MME_DATA(234):
    case NVCBC0_CALL_MME_DATA(235):
    case NVCBC0_CALL_MME_DATA(236):
    case NVCBC0_CALL_MME_DATA(237):
    case NVCBC0_CALL_MME_DATA(238):
    case NVCBC0_CALL_MME_DATA(239):
    case NVCBC0_CALL_MME_DATA(240):
    case NVCBC0_CALL_MME_DATA(241):
    case NVCBC0_CALL_MME_DATA(242):
    case NVCBC0_CALL_MME_DATA(243):
    case NVCBC0_CALL_MME_DATA(244):
    case NVCBC0_CALL_MME_DATA(245):
    case NVCBC0_CALL_MME_DATA(246):
    case NVCBC0_CALL_MME_DATA(247):
    case NVCBC0_CALL_MME_DATA(248):
    case NVCBC0_CALL_MME_DATA(249):
    case NVCBC0_CALL_MME_DATA(250):
    case NVCBC0_CALL_MME_DATA(251):
    case NVCBC0_CALL_MME_DATA(252):
    case NVCBC0_CALL_MME_DATA(253):
    case NVCBC0_CALL_MME_DATA(254):
    case NVCBC0_CALL_MME_DATA(255):


    P_DUMP_NVC9C0_MTHD_DATA(fp, idx, data, prefix);
    break;

          
    case NVCBC0_SET_NOTIFY_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.ADDRESS_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                      
    case NVCBC0_SET_REPORT_SEMAPHORE_ADDRESS_UPPER:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
              
    case NVCBC0_OFFSET_OUT_UPPER:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                              
    case NVCBC0_SET_I2M_SEMAPHORE_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                                                                                                                                  
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_NON_THROTTLED_C:

    
        parsed = (data >> 0) & ((1u << 9) - 1);
        fprintf(fp, "%s.MAX_SM_COUNT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 8) - 1);
        fprintf(fp, "%s.MAX_PLURAL_TPC_GPC_COUNT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 24) & ((1u << 8) - 1);
        fprintf(fp, "%s.MAX_SINGLETON_TPC_GPC_COUNT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
      
    case NVCBC0_SET_INLINE_QMD_ADDRESS_A:

    
        parsed = (data >> 0) & ((1u << 9) - 1);
        fprintf(fp, "%s.QMD_ADDRESS_SHIFTED8_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 30) & ((1u << 1) - 1);
        fprintf(fp, "%s.INLINE_SIZE = ", prefix);
        switch (parsed) {
        case NVCBC0_SET_INLINE_QMD_ADDRESS_A_INLINE_SIZE_INLINE_256:
            fprintf(fp, "INLINE_256\n");
            break;
        case NVCBC0_SET_INLINE_QMD_ADDRESS_A_INLINE_SIZE_INLINE_384:
            fprintf(fp, "INLINE_384\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                          
    case NVCBC0_SET_MME_MEM_ADDRESS_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                      
    case NVCBC0_SET_SHADER_LOCAL_MEMORY_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.ADDRESS_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
      
    case NVCBC0_SET_TEXTURE_HEADER_VERSION:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.MAJOR = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_A:

    
        parsed = data;
        fprintf(fp, "%s.LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVCBC0_SET_MONITORED_FENCE_SIGNAL_ADDRESS_BASE_B:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                              
    case NVCBC0_SET_TEX_SAMPLER_POOL_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NVCBC0_SET_TEX_HEADER_POOL_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                      
    case NVCBC0_SET_REPORT_SEMAPHORE_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
              
    case NVCBC0_SET_TRAP_HANDLER_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.ADDRESS_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                default:
        fprintf(fp, "%s.VALUE = 0x%x\n", prefix, data);
        break;
    }
}
